@@ -15,7 +15,7 @@ NAME = __name__.split('.')[-1] # package name (e.g. 'foo' or 'foo_bar')
                                # please use a all-lowercase valid python
                                # package name
 
-VERSION = '3.3.6' # version of the packaged files, please use the upstream
+VERSION = '3.3.7' # version of the packaged files, please use the upstream
                   # version number
 BUILD = '0' # our package build number, so we can release new builds
              # with fixes for xstatic stuff.
@@ -28,14 +28,14 @@ CLASSIFIERS = []
 KEYWORDS = 'bootswatch xstatic'
 
 # XStatic-* package maintainer:
-MAINTAINER = 'Diana Whitten'
-MAINTAINER_EMAIL = 'hurgleburgler@gmail.com'
+MAINTAINER = 'Rob Cresswell'
+MAINTAINER_EMAIL = 'robert.cresswell@outlook.com'
 
 # this refers to the project homepage of the stuff we packaged:
 HOMEPAGE = 'http://bootswatch.com'
 
 # this refers to all files:
-LICENSE = '(same as %s)' % DISPLAY_NAME
+LICENSE = 'MIT'
 
 from os.path import join, dirname
 BASE_DIR = join(dirname(__file__), 'data')
